import React from "react";
import { Story, Meta } from "@storybook/react/types-6-0";
// @ts-ignore
import styling from "@devcake/styling";
import { Select, SelectProps } from "./index";

export default {
  title: "Form/Select",
  component: Select,
  argTypes: {}
} as Meta;

const Template: Story<SelectProps> = (args) => <Select {...args} />;

export const Default = Template.bind({});
Default.args = {
  options: {
    "": "Geen van beide",
    "boy": "Boy",
    "mike": "Mike"
  }
};

export const Disabled = Template.bind({});
Disabled.args = {
  disabled: true,
  options: {
    "": "Geen van beide",
    "boy": "Boy",
    "mike": "Mike"
  },
  value: "mike"
};


export const Nullable = Template.bind({});
Nullable.args = {
  nullable: true,
  options: {
    "boy": "Boy",
    "mike": "Mike"
  },
  value: null
};

export const WithLabel = Template.bind({});
WithLabel.args = {
  label: "Selecteer een persoon",
  options: {
    "": "Geen van beide",
    "boy": "Boy",
    "mike": "Mike"
  }
};

export const WithCustomRenderer = Template.bind({});
WithCustomRenderer.args = {
  label: "Selecteer een persoon",
  options: {
    "boy": ["https://www.devcake.nl/wp-content/uploads/2019/11/Picture1-1.png", "Boy Bouw"],
    "mike": ["https://www.devcake.nl/wp-content/uploads/2019/11/Picture2-1.png", "Mike Slinkman"]
  },
  renderItem: (item, selected) => (
    <div className="flex">
      <img src={item[0]} className="w-10 w-10 mr-4" />

      <div className="text-lg block truncate flex items-center">{item[1]}</div>

      <div className="text-indigo-600 absolute inset-y-0 right-0 flex items-center pr-4">
        <svg className="h-5 w-5" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor">
          {selected && (
            <path
              fillRule="evenodd"
              d={styling.get("components.select.icons.check")}
              clipRule="evenodd"
            />
          )}
        </svg>
      </div>
    </div>
  )
};